/***************************************************************************
 *   This file is part of the propertyEditor project                       *
 *   Copyright (C) 2008 by BogDan Vatra                                    *
 *   bog_dan_ro@yahoo.com                                                  *
 **                   GNU General Public License Usage                    **
 *                                                                         *
 *   This library is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 **                  GNU Lesser General Public License                    **
 *                                                                         *
 *   This library is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        * 
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library.                                      * 
 *   If not, see <http://www.gnu.org/licenses/>.                           *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 ****************************************************************************/

#include <QtCore>
#include <QMetaProperty>
#include <QMetaEnum>

#include "brush.h"

Brush::Brush(QObject* parent, QObject* object, int property, const PropertyModel * propertyModel): PropertyInterface(parent, object, property, propertyModel)
{
	refreshPropertis(propertyModel);
}


QWidget* Brush::createEditor(QWidget * parent, const QModelIndex & index)
{
	Q_UNUSED(index);
	Q_UNUSED(parent);
	return 0;
}

QVariant Brush::data(const QModelIndex & index)
{
	switch (index.column())
	{
		case 0:
			return object()->metaObject()->property(objectProperty()).name();
		case 1:
			return value();
	}
	return QVariant();
}

bool Brush::setData(QVariant data, const QModelIndex & index)
{
	Q_UNUSED(data);
	Q_UNUSED(index);
	return false;
}

bool Brush::canHandle(QObject * object, int property) const
{
	if (object->metaObject()->property(property).isEnumType() || object->metaObject()->property(property).isFlagType())
		return false;
	switch (object->property(object->metaObject()->property(property).name()).type())
	{
		case QVariant::Brush:
			return true;
		default:
			return false;
	}
	return false;
}

Brush::BrushStyle Brush::style()
{
	return (Brush::BrushStyle)value().value<QBrush>().style();
}

void Brush::setStyle(Brush::BrushStyle style)
{
	QBrush b = value().value<QBrush>();
	b.setStyle((Qt::BrushStyle)style);
	setValue(b);
}

QColor Brush::color()
{
	return value().value<QBrush>().color();
}

void Brush::setColor(QColor color)
{
	QBrush b = value().value<QBrush>();
	b.setColor(color);
	setValue(b);
}

QPixmap Brush::texture()
{
	return value().value<QBrush>().texture();
}

void Brush::setTexture(const QPixmap & texture)
{
	QBrush b = value().value<QBrush>();
	b.setTexture(texture);
	setValue(b);
}

Qt::ItemFlags Brush::flags(const QModelIndex &/*index*/)
{
	return Qt::ItemIsEnabled;
}

PropertyInterface* Brush::createInstance(QObject * object, int property, const PropertyModel * propertyModel) const
{
	return new Brush(parent(), object, property, propertyModel);
}

Q_EXPORT_PLUGIN2(brush, Brush);
